<?php

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/


use Illuminate\Support\Facades\Route;
use Modules\Pd\Http\Controllers\DailyProductionController;
use Modules\Pd\Http\Controllers\DailyProductionListController;
use Modules\Pd\Http\Controllers\DailyProductionReportController;
use Modules\Pd\Http\Controllers\ProductionRecordsReportController;
use Modules\Pd\Http\Controllers\ProductionScheduleCalendarController;
use Modules\Pd\Http\Controllers\ProductionScheduleCreateController;
use Modules\Pd\Http\Controllers\ProductionScheduleGanttChartController;
use Modules\Pd\Http\Controllers\ProductionScheduleListController;
use Modules\Pp\Http\Controllers\GanttChartController;

Route::prefix('pd')->group(function () {
    //Route::get('/', 'PpController@index');

    Route::get('/dashboard', function () {
        return view('pd::dashboard');
    })->middleware('is.logged');

    Route::get('/daily_production', function () {
        return view('pd::daily_production'); 
    })->middleware('is.logged');

    Route::get('/daily_production_list', function () {
        return view('pd::daily_production_list');
    })->middleware('is.logged');

    Route::get('/production_schedule_create', function () {
        return view('pd::production_schedule');
    })->middleware('is.logged');

    Route::get('/production_schedule_list', function () {
        return view('pd::production_schedule_list');
    })->middleware('is.logged');


    Route::get('/production_schedule_calendar', function () {
        return view('pd::calendar');
    })->middleware('is.logged');



    Route::get('/production_schedule_gantt_chart', function () {
        return view('pd::gantt_chart');
    })->middleware('is.logged');


    Route::get('/MachineryModal', function () {
        return view('pd::MachineryModal');
    })->middleware('is.logged');


    Route::get('/BomModal', function () {
        return view('pd::BomModal');
    })->middleware('is.logged');

    Route::get('/HrModal', function () {
        return view('pd::HrModal');
    })->middleware('is.logged');



    Route::get('/daily_production_report', function () {
        return view('pd::daily_production_report');
    })->middleware('is.logged');

    Route::get('/production_records_report', function () {
        return view('pd::production_records_report');
    })->middleware('is.logged');



    /**Daily Production Controller */
    Route::get('/DailyProductionController/productionSupervisor', [DailyProductionController::class, 'productionSupervisor']);
    Route::get('/DailyProductionController/manufacturingOrderNumber', [DailyProductionController::class, 'manufacturingOrderNumber']);
    Route::get('/DailyProductionController/product/{id}', [DailyProductionController::class, 'product']);
    Route::get('/DailyProductionController/machine/{id}', [DailyProductionController::class, 'machine']);
    Route::post('/DailyProductionController/save', [DailyProductionController::class, 'save']);
    Route::post('/DailyProductionController/update/{id}', [DailyProductionController::class, 'update']);
    Route::get('/DailyProductionController/getDailyProduction/{id}', [DailyProductionController::class, 'getDailyProduction']);
    /**End of Daily Production Controller */

    /**Daily Production List Controller */
    Route::get('/DailyProductionListController/allDailyProduction', [DailyProductionListController::class, 'allDailyProduction']);
    Route::delete('/DailyProductionListController/delete/{id}', [DailyProductionListController::class, 'delete']);
    /**End of Daily Production List Controller */


    /**Production Schedule Create Controller */
    Route::get('/ProductionScheduleCreateController/productionPlan', [ProductionScheduleCreateController::class, 'productionPlan']);
    Route::get('/ProductionScheduleCreateController/getSelectedProductData/{customer_order_plan_data_id}/{product_primary_id}/{machinery_id}', [ProductionScheduleCreateController::class, 'getSelectedProductData']);
    Route::get('/ProductionScheduleCreateController/getAllocatedQuantityFromDate/{order_id}/{product_id}/{machine_id}/{date}/{from}/{to}', [ProductionScheduleCreateController::class, 'getAllocatedQuantityFromDate']);
    Route::get('/ProductionScheduleCreateController/getAllocatedData/{order_id}/{product_id}/{machine_id}', [ProductionScheduleCreateController::class, 'getAllocatedData']);
    Route::get('/ProductionScheduleCreateController/quantityPerHour/{machine_id}', [ProductionScheduleCreateController::class, 'quantityPerHour']);
    Route::get('/ProductionScheduleCreateController/getSavedAllocatedBOMData/{customer_order_plan_data_id}/{fg_product_id}', [ProductionScheduleCreateController::class, 'getSavedAllocatedBOMData']);
    Route::get('/ProductionScheduleCreateController/getSaveProductionTeam/{customer_order_plan_data_id}/{fg_product_id}', [ProductionScheduleCreateController::class, 'getSaveProductionTeam']);
    Route::get('/ProductionScheduleCreateController/getMachineryShifts/{customer_order_plan_data_id}', [ProductionScheduleCreateController::class, 'getMachineryShifts']);
    Route::get('/ProductionScheduleCreateController/getSavedAllocatedDataToDetailsHR/{customer_order_plan_data_id}/{fg_product_id}/{shift_id}', [ProductionScheduleCreateController::class, 'getSavedAllocatedDataToDetailsHR']);
    Route::post('/ProductionScheduleCreateController/add', [ProductionScheduleCreateController::class, 'add']);
    Route::get('/ProductionScheduleCreateController/getSelectedDailyProduction/{order_id}', [ProductionScheduleCreateController::class, 'getSelectedDailyProduction']);
    Route::get('/ProductionScheduleCreateController/factories', [ProductionScheduleCreateController::class, 'factories']);
    Route::get('/ProductionScheduleCreateController/loadMachinesToFactory/{id}', [ProductionScheduleCreateController::class, 'loadMachinesToFactory']);
    Route::get('/ProductionScheduleCreateController/allShift', [ProductionScheduleCreateController::class, 'allShift']);
    Route::get('/ProductionScheduleCreateController/getSelectedProductDataToMaterial/{customer_order_plan_data_id}/{product_primary_id}', [ProductionScheduleCreateController::class, 'getSelectedProductDataToMaterial']);
    Route::get('/ProductionScheduleCreateController/getAllocatedBOMData/{product_code}/{bom_name}', [ProductionScheduleCreateController::class, 'getAllocatedBOMData']);
    Route::get('/ProductionScheduleCreateController/allRawMaterialProducts', [ProductionScheduleCreateController::class, 'allRawMaterialProducts']);
    /**End of Production Schedule Create Controller */


    /**Production Schedule List Controller */
    Route::get('/ProductionScheduleListController/productionPlan', [ProductionScheduleListController::class, 'productionPlan']);
    Route::post('/ProductionScheduleListController/saveAllocateToMachine', [ProductionScheduleListController::class, 'saveAllocateToMachine']);
    Route::get('/ProductionScheduleListController/getAllocatedData/{order_id}/{product_id}/{machine_id}', [ProductionScheduleListController::class, 'getAllocatedData']);
    Route::get('/ProductionScheduleListController/getSavedAllocatedBOMData/{customer_order_plan_data_id}/{fg_product_id}', [ProductionScheduleListController::class, 'getSavedAllocatedBOMData']);
    Route::post('/ProductionScheduleListController/saveScheduleToBOM', [ProductionScheduleListController::class, 'saveScheduleToBOM']);
    Route::get('/ProductionScheduleListController/getSaveProductionTeam/{customer_order_plan_data_id}/{fg_product_id}/{shift_id}', [ProductionScheduleListController::class, 'getSaveProductionTeam']);
    Route::post('/ProductionScheduleListController/saveAllocateToHR', [ProductionScheduleListController::class, 'saveAllocateToHR']);
    /**End of Production Schedule List Controller */



    /**Production Schedule Calendar Controller */
    Route::get('/ProductionScheduleCalendarController/loadProductionPlanToCalander', [ProductionScheduleCalendarController::class, 'loadProductionPlanToCalander']);
    /**End of Production Schedule Calendar Controller */



    /** Gantt Chart */
    Route::get('/ProductionScheduleGanttChartController/createGantChart/{startDate}/{endDate}', [ProductionScheduleGanttChartController::class, 'createGantChart']);
    Route::get('/ProductionScheduleGanttChartController/ganttChartModalData/{customer_order_id}/{machine_id}/{startDate}/{endDate}', [ProductionScheduleGanttChartController::class, 'ganttChartModalData']);
    Route::get('/ProductionScheduleGanttChartController/loadProducts', [ProductionScheduleGanttChartController::class, 'loadProducts']);
    Route::get('/ProductionScheduleGanttChartController/loadMachine', [ProductionScheduleGanttChartController::class, 'loadMachine']);
    Route::get('/ProductionScheduleGanttChartController/loadOrder', [ProductionScheduleGanttChartController::class, 'loadOrder']);
    Route::get('/ProductionScheduleGanttChartController/searchGantChart/{setting}/{startDate}/{endDate}', [ProductionScheduleGanttChartController::class, 'searchGantChart']);
    /** End of Gantt Chart */


    /** Daily Production Report Controller */
    Route::get('/DailyProductionReportController/sites', [DailyProductionReportController::class, 'sites']);
    Route::get('/DailyProductionReportController/dailyProductionReport/{search_option}', [DailyProductionReportController::class, 'dailyProductionReport']);
    /** End of Daily Production Report Controller */

    /** Production Records Report Controller */
    Route::get('/ProductionRecordsReportController/allSettings', [ProductionRecordsReportController::class, 'allSettings']);
    Route::get('/ProductionRecordsReportController/productionRecordsReport/{search_option}/{date_from}/{date_to}', [ProductionRecordsReportController::class, 'productionRecordsReport']);
    /** End of Production Records Report Controller */
});
